@@ -6,8 +6,6 @@ import static com.openexchange.util.custom.base.NullUtil.logger;
 import static com.openexchange.util.custom.base.NullUtil.notNull;
 import java.util.Dictionary;
 import java.util.Hashtable;
-import javax.annotation.Nullable;
-import javax.annotation.ParametersAreNonnullByDefault;
 import javax.annotation.concurrent.ThreadSafe;
 import javax.management.MalformedObjectNameException;
 import javax.management.ObjectName;
@@ -19,6 +17,7 @@ import org.osgi.util.tracker.ServiceTrackerCustomizer;
 import org.slf4j.Logger;
 import com.openexchange.ajax.login.LoginRequestHandler;
 import com.openexchange.ajax.requesthandler.AJAXActionService;
+import com.openexchange.annotation.Nullable;
 import com.openexchange.groupware.update.DefaultUpdateTaskProviderService;
 import com.openexchange.groupware.update.UpdateTaskV2;
 import com.openexchange.management.Managements;
@@ -115,7 +114,6 @@ public final SomeServiceClassImpl implements SomeServiceClass {
  * @author <a href="mailto:pascal.bleser@open-xchange.com">Pascal Bleser</a>
  * @since v1.0.0
  */
-@ParametersAreNonnullByDefault
 @ThreadSafe
 public abstract class ActivatorTemplate implements BundleActivator {
 
