@@ -52,9 +52,8 @@ package com.openexchange.util.activator;
 import java.lang.annotation.Annotation;
 import java.lang.reflect.Constructor;
 import java.lang.reflect.Method;
-import javax.annotation.Nullable;
-import javax.annotation.ParametersAreNonnullByDefault;
 import com.google.common.base.Optional;
+import com.openexchange.annotation.Nullable;
 
 
 /**
@@ -63,7 +62,6 @@ import com.google.common.base.Optional;
  * @author <a href="mailto:pascal.bleser@open-xchange.com">Pascal Bleser</a>
  * @since v7.8.2
  */
-@ParametersAreNonnullByDefault
 public interface ServiceDependencyResolver {
     @Nullable <X> X resolveMandatoryService(final Class<X> serviceClass, final @Nullable Annotation[] annotations);
     @Nullable <X> ServiceRef<X> resolveOptionalService(final Class<X> serviceClass, final @Nullable Annotation[] annotations);
