@@ -56,7 +56,6 @@ import static com.openexchange.util.activator.impl.RegistrationTools.setOfServic
 import static com.openexchange.util.custom.base.NullUtil.className;
 import static com.openexchange.util.custom.base.NullUtil.f;
 import static com.openexchange.util.custom.base.NullUtil.logger;
-import static com.openexchange.util.custom.base.NullUtil.notNull;
 import java.lang.annotation.Annotation;
 import java.lang.reflect.Constructor;
 import java.lang.reflect.InvocationTargetException;
@@ -64,17 +63,16 @@ import java.util.Dictionary;
 import java.util.HashSet;
 import java.util.List;
 import java.util.Set;
-import javax.annotation.Nonnull;
-import javax.annotation.Nullable;
-import javax.annotation.ParametersAreNonnullByDefault;
+import java.util.stream.Collectors;
+import java.util.stream.Stream;
 import javax.annotation.concurrent.Immutable;
 import org.osgi.framework.BundleContext;
 import org.osgi.util.tracker.ServiceTrackerCustomizer;
 import org.slf4j.Logger;
-import com.google.common.base.Joiner;
 import com.google.common.base.Optional;
-import com.google.common.collect.FluentIterable;
 import com.google.common.collect.ImmutableSet;
+import com.openexchange.annotation.NonNull;
+import com.openexchange.annotation.Nullable;
 import com.openexchange.osgi.ServiceListing;
 import com.openexchange.osgi.ServiceSet;
 import com.openexchange.util.activator.Property;
@@ -94,11 +92,11 @@ import com.openexchange.util.activator.SetOfServices;
  * @param <S>
  * @param <T>
  */
-@ParametersAreNonnullByDefault
 @Immutable
 public abstract class ClassServiceWithDependenciesTemplate<S, T extends S> extends ServiceWithDependenciesTemplate<S, T> {
     
-    private static final ImmutableSet<Class<?>> CLASSES_THAT_REQUIRE_SET_OF_SERVICES_ANNOTATION = ImmutableSet.<Class<?>>of(
+    @SuppressWarnings("null")
+    private static final @NonNull ImmutableSet<Class<?>> CLASSES_THAT_REQUIRE_SET_OF_SERVICES_ANNOTATION = ImmutableSet.<Class<?>>of(
         ServiceSet.class,
         ServiceListing.class
     );
@@ -244,12 +242,21 @@ public abstract class ClassServiceWithDependenciesTemplate<S, T extends S> exten
             }
         }
         
+        @SuppressWarnings("null")
+        final @NonNull ImmutableSet<MandatoryServiceDependency<?>> immutableMandatoryServices = ImmutableSet.copyOf(mandatoryServices);
+        @SuppressWarnings("null")
+        final @NonNull ImmutableSet<OptionalServiceDependency<?>> immutableOptionalServices = ImmutableSet.copyOf(optionalServices);
+        @SuppressWarnings("null")
+        final @NonNull ImmutableSet<Class<?>> immutableServiceSets = ImmutableSet.copyOf(serviceSets);
+        @SuppressWarnings("null")
+        final @NonNull ImmutableSet<Class<?>> immutableServiceListings = ImmutableSet.copyOf(serviceListings);
+        
         return new DependencyScan<>(
             ctor,
-            ImmutableSet.copyOf(mandatoryServices),
-            ImmutableSet.copyOf(optionalServices),
-            ImmutableSet.copyOf(serviceSets),
-            ImmutableSet.copyOf(serviceListings)
+            immutableMandatoryServices,
+            immutableOptionalServices,
+            immutableServiceSets,
+            immutableServiceListings
         );
     }
     
@@ -263,7 +270,14 @@ public abstract class ClassServiceWithDependenciesTemplate<S, T extends S> exten
         ImmutableSet<OptionalServiceDependency<?>> optionalDependencies,
         ImmutableSet<Class<?>> serviceSets,
         ImmutableSet<Class<?>> serviceListings) {
-        super(serviceInstanceClass, serviceClass, mandatoryDependencies, optionalDependencies, serviceSets, serviceListings);
+        super(
+            serviceInstanceClass,
+            serviceClass,
+            mandatoryDependencies,
+            optionalDependencies,
+            serviceSets,
+            serviceListings
+        );
         this.constructor = constructor;
     }
     
@@ -273,11 +287,14 @@ public abstract class ClassServiceWithDependenciesTemplate<S, T extends S> exten
         final Dictionary<String, ?> properties,
         final @Nullable ServiceRegistrationHandler<T> serviceRegistrationHandler) {
         
+        @SuppressWarnings("null")
+        final @NonNull String name = serviceInstanceClass.getName();
+        
         return new ServiceWithDependenciesServiceRegisterer<>(bundleContext,
             registry,
             this,
             serviceClasses,
-            notNull(serviceInstanceClass.getName()),
+            name,
             properties,
             serviceRegistrationHandler
         );
@@ -295,7 +312,7 @@ public abstract class ClassServiceWithDependenciesTemplate<S, T extends S> exten
                 }
                 return result;
             } catch (final Exception e) {
-                @Nonnull Throwable t = e;
+                @NonNull Throwable t = e;
                 if (t instanceof InvocationTargetException) {
                     final Throwable c = t.getCause();
                     if (c != null) {
@@ -306,7 +323,7 @@ public abstract class ClassServiceWithDependenciesTemplate<S, T extends S> exten
                 LOG.debug(f("failed to invoke service %s constructor \"%s\" with parameters [%s]: %s: %s",
                     className(serviceInstanceClass),
                     constructor.toGenericString(),
-                    FluentIterable.of(values.get()).transform(RegistrationTools.TO_CLASS_NAME).join(Joiner.on(", ")),
+                    Stream.of(values.get()).map(RegistrationTools.TO_CLASS_NAME).collect(Collectors.joining(", ")),
                     className(t), t.getMessage()), t);
                 if (t instanceof RegistrationException) {
                     throw (RegistrationException) t;
