@@ -49,8 +49,9 @@
 
 package com.openexchange.util.activator.impl;
 
-import javax.annotation.Nullable;
-import javax.annotation.ParametersAreNonnullByDefault;
+
+
+import com.openexchange.annotation.Nullable;
 import com.openexchange.util.activator.DependencyProvider;
 import com.openexchange.util.activator.ServiceDependencyResolver;
 
@@ -61,7 +62,6 @@ import com.openexchange.util.activator.ServiceDependencyResolver;
  * @author <a href="mailto:pascal.bleser@open-xchange.com">Pascal Bleser</a>
  * @since v1.0.0
  */
-@ParametersAreNonnullByDefault
 public class DependencyProviderServiceWithDependencies<S, T extends S> extends ServiceWithDependenciesTemplate<S, T> {
 
     private final T serviceInstance;
