@@ -56,7 +56,6 @@ import static com.openexchange.util.custom.base.NullUtil.notNull;
 import java.io.Closeable;
 import java.io.IOException;
 import java.util.ArrayList;
-import java.util.Collection;
 import java.util.HashSet;
 import java.util.Iterator;
 import java.util.List;
@@ -64,15 +63,16 @@ import java.util.Locale;
 import java.util.Map;
 import java.util.Set;
 import java.util.concurrent.atomic.AtomicReference;
-import javax.annotation.Nullable;
-import javax.annotation.ParametersAreNonnullByDefault;
+
+
 import org.slf4j.Logger;
 import com.google.common.base.Joiner;
 import com.google.common.collect.ImmutableMap;
 import com.google.common.collect.ImmutableSet;
 import com.openexchange.ajax.requesthandler.AJAXActionService;
 import com.openexchange.ajax.requesthandler.AJAXActionServiceFactory;
-import com.openexchange.documentation.annotations.Action;
+import com.openexchange.annotation.NonNull;
+import com.openexchange.annotation.Nullable;
 import com.openexchange.exception.OXException;
 import com.openexchange.tools.servlet.AjaxExceptionCodes;
 import com.openexchange.util.activator.AjaxAction;
@@ -82,29 +82,26 @@ import com.openexchange.util.activator.ServiceDependencies;
 import com.openexchange.util.activator.ServiceDependencyResolver;
 
 /**
- * {@link AJAXActionServiceFactory} implementation that uses the {@code @}{@link Action}
- * (deprecated) or {@code @}{@link AjaxAction} annotation to discover {@link AJAXActionService}
- * implementations.
+ * {@link AJAXActionServiceFactory} implementation that uses the {@code @}{@link AjaxAction}
+ * annotation to discover {@link AJAXActionService} implementations.
  * <p>
- * Note that if a class is annotated with neither {@code @}{@link Action} nor
- * {@code @}{@link AJAXActionService}, it will attempt to infer its action from the beginning
- * of its class name (e.g. {@code GetFooAction} yields {@code "get"}), but that approach
- * is less deterministic and the preferred method is to use the {@code @}{@link AjaxAction}
- * annotation.
+ * Note that if a class is not annotated with {@code @}{@link AJAXActionService}, it will
+ * attempt to infer its action from the beginning of its class name (e.g. {@code GetFooAction}
+ * yields {@code "get"}), but that approach is less deterministic and the preferred method is
+ * to use the {@code @}{@link AjaxAction} annotation.
  * <p>
  * See {@link #CLASS_NAME_PREFIX_ACTION} for a list of supported class name prefixes.
  *
  * @author <a href="mailto:pascal.bleser@open-xchange.com">Pascal Bleser</a>
  * @since v7.8.2
  */
-@SuppressWarnings("deprecation")
-@ParametersAreNonnullByDefault
 public final class DiscoveringActionFactory implements AJAXActionServiceFactory, DependencyProvider, Closeable {
     
     private static final Logger LOG = logger(DiscoveringActionFactory.class);
     
-    public static final ImmutableSet<String> CLASS_NAME_PREFIX_ACTION = ImmutableSet.of(
-        "Get", "Set", "List", "Delete", "All", "Copy", "New", "Move", "Edit", "Update", "Search"
+    @SuppressWarnings("null")
+    public static final @NonNull ImmutableSet<String> CLASS_NAME_PREFIX_ACTION = ImmutableSet.of(
+        "Default", "Get", "Set", "List", "Delete", "All", "Copy", "New", "Move", "Edit", "Update", "Search"
     );
     
     private final String module;
@@ -121,13 +118,9 @@ public final class DiscoveringActionFactory implements AJAXActionServiceFactory,
             for (final Class<? extends AJAXActionService> c : ajaxActionServiceClasses) {
                 final ImmutableSet<String> actions;
                 {
-                    final Action action = c.getAnnotation(Action.class);
                     final AjaxAction ajaxAction = c.getAnnotation(AjaxAction.class);
                     if (ajaxAction != null) {
-                        // AjaxAction wins, we just ignore the @Action annotation
                         actions = ImmutableSet.copyOf(notNull(ajaxAction.value()));
-                    } else if (action != null) {
-                        actions = ImmutableSet.of(notNull(action.name()));
                     } else {
                         String a = null;
                         final Iterator<String> iter = CLASS_NAME_PREFIX_ACTION.iterator();
@@ -172,19 +165,30 @@ public final class DiscoveringActionFactory implements AJAXActionServiceFactory,
                     serviceSetsBuilder.addAll(d.serviceSetClasses());
                     serviceListingsBuilder.addAll(d.serviceListingClasses());
                 }
+                    
+                @SuppressWarnings("null")
+                final @NonNull ImmutableSet<MandatoryServiceDependency<?>> mandatoryDependencies = ImmutableSet.copyOf(mandatoryDependenciesBuilder);
+                @SuppressWarnings("null")
+                final @NonNull ImmutableSet<OptionalServiceDependency<?>> optionalDependencies = ImmutableSet.copyOf(optionalDependenciesBuilder);
+                @SuppressWarnings("null")
+                final @NonNull ImmutableSet<Class<?>> serviceSets = ImmutableSet.copyOf(serviceSetsBuilder);
+                @SuppressWarnings("null")
+                final @NonNull ImmutableSet<Class<?>> serviceListings = ImmutableSet.copyOf(serviceListingsBuilder);
+                
                 this.needs = new ImmutableServiceDependencies(
-                    ImmutableSet.copyOf(mandatoryDependenciesBuilder),
-                    ImmutableSet.copyOf(optionalDependenciesBuilder),
-                    ImmutableSet.copyOf(serviceSetsBuilder),
-                    ImmutableSet.copyOf(serviceListingsBuilder)
+                    mandatoryDependencies,
+                    optionalDependencies,
+                    serviceSets,
+                    serviceListings
                 );                
             }
-            this.actions = actionsBuilder.build();
+            @SuppressWarnings("null")
+            final @NonNull ImmutableMap<String, Class<? extends AJAXActionService>> a = actionsBuilder.build();
+            this.actions = a;
         }
         this.instancesRef = new AtomicReference<>(ImmutableMap.<String,AJAXActionService>of());
     }
 
-    @SuppressWarnings({ "null", "unused" })
     @Override
     public AJAXActionService createActionService(final @Nullable String action) throws OXException {
         final AJAXActionService service = instancesRef.get().get(action);
@@ -195,11 +199,6 @@ public final class DiscoveringActionFactory implements AJAXActionServiceFactory,
         }
     }
 
-    @Override
-    public Collection<?> getSupportedServices() {
-        return actions.values();
-    }
-
     @Override
     public ServiceDependencies dependsOn() {
         return needs;
