@@ -52,17 +52,18 @@ package com.openexchange.util.activator.impl;
 import static com.openexchange.util.activator.impl.RegistrationTools.TO_SIMPLE_CLASS_NAME;
 import static com.openexchange.util.custom.base.NullUtil.className;
 import static com.openexchange.util.custom.base.NullUtil.f;
+import static com.openexchange.util.custom.base.NullUtil.logger;
+import java.util.Collection;
 import java.util.Dictionary;
 import java.util.Set;
 import java.util.concurrent.atomic.AtomicReference;
-import javax.annotation.Nonnull;
+import java.util.stream.Collectors;
 import javax.annotation.concurrent.ThreadSafe;
 import org.osgi.framework.BundleContext;
 import org.osgi.framework.ServiceRegistration;
-import com.google.common.base.Joiner;
-import com.google.common.collect.FluentIterable;
 import com.google.common.collect.ImmutableMap;
 import com.google.common.collect.ImmutableSet;
+import com.openexchange.annotation.Nullable;
 import com.openexchange.osgi.ExceptionUtils;
 import com.openexchange.osgi.ServiceListing;
 import com.openexchange.osgi.ServiceSet;
@@ -77,28 +78,29 @@ import com.openexchange.util.activator.ServiceDependencyResolver;
 @ThreadSafe
 public abstract class InstanceFactoryServiceAwareDependentServiceRegistererTemplate<S, T extends S> extends ServiceAwareDependentServiceRegistererTemplate<S, T> {
 
-    private static final org.slf4j.Logger LOG = org.slf4j.LoggerFactory.getLogger(InstanceFactoryServiceAwareDependentServiceRegistererTemplate.class);
+    private static final org.slf4j.Logger LOG = logger(InstanceFactoryServiceAwareDependentServiceRegistererTemplate.class);
     
     private final AtomicReference<ServiceRegistrationSet<T>> registrationRef;
     
-    public InstanceFactoryServiceAwareDependentServiceRegistererTemplate(@Nonnull BundleContext context,
-        @Nonnull ImmutableSet<Class<?>> serviceTypes,
-        @Nonnull String serviceInstanceName,
-        @Nonnull Dictionary<String, ?> properties,
-        @Nonnull Iterable<MandatoryServiceDependency<?>> mandatoryServices,
-        @Nonnull Iterable<OptionalServiceDependency<?>> optionalServices,
-        @Nonnull ImmutableMap<Class<?>, ServiceSet<?>> serviceSets,
-        @Nonnull ImmutableMap<Class<?>, ServiceListing<?>> serviceListings,
-        @Nonnull Set<String> propertiesOfInterest) {
+    public InstanceFactoryServiceAwareDependentServiceRegistererTemplate(
+        BundleContext context,
+        ImmutableSet<Class<?>> serviceTypes,
+        String serviceInstanceName,
+        Dictionary<String, ?> properties,
+        Collection<MandatoryServiceDependency<?>> mandatoryServices,
+        Collection<OptionalServiceDependency<?>> optionalServices,
+        ImmutableMap<Class<?>, ServiceSet<?>> serviceSets,
+        ImmutableMap<Class<?>, ServiceListing<?>> serviceListings,
+        Set<String> propertiesOfInterest) {
         super(context, serviceTypes, serviceInstanceName, properties, mandatoryServices, optionalServices,
             serviceSets, serviceListings, propertiesOfInterest);
         this.registrationRef = new AtomicReference<ServiceRegistrationSet<T>>(null);
     }
 
-    protected abstract @Nonnull T createInstance(final @Nonnull ServiceDependencyResolver resolver) throws Exception;
+    protected abstract T createInstance(final ServiceDependencyResolver resolver) throws Exception;
 
     @Override
-    protected Object register(final ServiceDependencyResolver resolver) {
+    protected @Nullable Object register(final @Nullable ServiceDependencyResolver resolver) {
         if (resolver == null) {
             throw new IllegalArgumentException(f("%s parameter is null", ServiceDependencyResolver.class.getName()));
         }
@@ -107,7 +109,7 @@ public abstract class InstanceFactoryServiceAwareDependentServiceRegistererTempl
             if (LOG.isTraceEnabled()) {
                 LOG.trace("registering service {} ({})",
                     className(serviceInstance),
-                    FluentIterable.from(serviceTypes).transform(TO_SIMPLE_CLASS_NAME).join(Joiner.on(", ")));
+                    serviceTypes.stream().map(TO_SIMPLE_CLASS_NAME).collect(Collectors.joining(", ")));
             }
             final ServiceRegistration<?> r = RegistrationTools
                 .registerIntoContext(context, serviceTypes, serviceInstance, properties);
@@ -117,7 +119,7 @@ public abstract class InstanceFactoryServiceAwareDependentServiceRegistererTempl
             ExceptionUtils.handleThrowable(t);
             LOG.error(f("failed to register %s (%s)",
                 serviceInstanceName,
-                FluentIterable.from(serviceTypes).transform(TO_SIMPLE_CLASS_NAME).join(Joiner.on(", "))),
+                serviceTypes.stream().map(TO_SIMPLE_CLASS_NAME).collect(Collectors.joining(", "))),
                 t);
             return null;
         }
@@ -129,7 +131,7 @@ public abstract class InstanceFactoryServiceAwareDependentServiceRegistererTempl
         if (LOG.isTraceEnabled()) {
             LOG.trace("Unregistering service {} ({})",
                 serviceInstanceName,
-                FluentIterable.from(serviceTypes).transform(TO_SIMPLE_CLASS_NAME).join(Joiner.on(", "))
+                serviceTypes.stream().map(TO_SIMPLE_CLASS_NAME).collect(Collectors.joining(", "))
             );
         }
         
