@@ -95,6 +95,7 @@ import org.osgi.framework.ServiceRegistration;
 import org.osgi.util.tracker.ServiceTracker;
 import org.osgi.util.tracker.ServiceTrackerCustomizer;
 import org.slf4j.Logger;
+import com.google.common.base.CharMatcher;
 import com.google.common.base.Joiner;
 import com.google.common.base.Optional;
 import com.google.common.collect.ImmutableList;
@@ -775,7 +776,11 @@ public enum RegistrationTools {
         final String module,
         final Class<? extends AJAXActionService>... actions) {
         final Hashtable<String, Object> properties = new Hashtable<>(2);
-        properties.put("module", module);
+        final String sanitizedModule = sanitizeModule(module);
+        if (! module.equals(sanitizedModule)) {
+            LOG.warn("sanitized module name '%s' to '%s'", module, sanitizedModule);
+        }
+        properties.put("module", sanitizedModule);
         properties.put("multiple", true);
         
         final ImmutableSet<Class<? extends AJAXActionService>> actionSet;
@@ -791,7 +796,7 @@ public enum RegistrationTools {
         
         registerServiceInstance(bundleContext, registry,
             AJAXActionServiceFactory.class,
-            new DiscoveringActionFactory(module, actionSet),
+            new DiscoveringActionFactory(sanitizedModule, actionSet),
             properties,
             null
         );
@@ -1085,5 +1090,13 @@ public enum RegistrationTools {
         }
         return NullUtil.immutableSetCopyOf(set);
     }
+    
+    @SuppressWarnings("null")
+    private static final @NonNull CharMatcher SLASH_MATCHER = CharMatcher.is('/');
+    
+    @SuppressWarnings("null")
+    public static final String sanitizeModule(final String module) {
+        return SLASH_MATCHER.trimAndCollapseFrom(module, '/');
+    }
 
 }
