@@ -54,7 +54,10 @@ import static com.openexchange.util.activator.impl.RegistrationTools.serviceAnno
 import static com.openexchange.util.activator.impl.RegistrationTools.serviceClassAnnotation;
 import static com.openexchange.util.activator.impl.RegistrationTools.setOfServicesAnnotation;
 import static com.openexchange.util.custom.base.NullUtil.className;
+import static com.openexchange.util.custom.base.NullUtil.emptyList;
 import static com.openexchange.util.custom.base.NullUtil.f;
+import static com.openexchange.util.custom.base.NullUtil.immutableCopyOf;
+import static com.openexchange.util.custom.base.NullUtil.immutableSetCopyOf;
 import static com.openexchange.util.custom.base.NullUtil.logger;
 import static com.openexchange.util.custom.base.NullUtil.notNull;
 import java.lang.annotation.Annotation;
@@ -64,14 +67,13 @@ import java.util.ArrayList;
 import java.util.HashSet;
 import java.util.List;
 import java.util.Set;
-import javax.annotation.Nullable;
-import javax.annotation.ParametersAreNonnullByDefault;
+import java.util.stream.Collectors;
+import java.util.stream.Stream;
 import org.slf4j.Logger;
-import com.google.common.base.Joiner;
 import com.google.common.base.Optional;
-import com.google.common.collect.FluentIterable;
 import com.google.common.collect.ImmutableList;
 import com.google.common.collect.ImmutableSet;
+import com.openexchange.annotation.Nullable;
 import com.openexchange.osgi.ServiceListing;
 import com.openexchange.osgi.ServiceSet;
 import com.openexchange.util.activator.Property;
@@ -90,14 +92,13 @@ import com.openexchange.util.activator.SetOfServices;
  * @author <a href="mailto:pascal.bleser@open-xchange.com">Pascal Bleser</a>
  * @since v1.0.2
  */
-@ParametersAreNonnullByDefault
 public final class ServiceFactoryWithDependencies<S, T extends S> extends ServiceWithDependenciesTemplate<S, T> {
     
     private static final Logger LOG = logger(ServiceFactoryWithDependencies.class);
 
     private static final <T> ImmutableList<Method> serviceFactoryMethods(final @Nullable Method[] methods) {
         if (methods == null) {
-            return ImmutableList.of();
+            return emptyList();
         }
         final List<Method> list = new ArrayList<>();
         for (final Method m : methods) {
@@ -120,7 +121,7 @@ public final class ServiceFactoryWithDependencies<S, T extends S> extends Servic
                 }
             }
         }
-        return ImmutableList.copyOf(list);
+        return immutableCopyOf(list);
     }
     
     public static final <X> ServiceWithDependencies<X> find(final ServiceFactory<X> serviceFactory) {
@@ -228,10 +229,10 @@ public final class ServiceFactoryWithDependencies<S, T extends S> extends Servic
             }
         }
         return new ServiceFactoryWithDependencies<X, X>(serviceFactory, ctor,
-            ImmutableSet.copyOf(mandatoryServices),
-            ImmutableSet.copyOf(optionalServices),
-            ImmutableSet.copyOf(serviceSets),
-            ImmutableSet.copyOf(serviceListings)
+            immutableSetCopyOf(mandatoryServices),
+            immutableSetCopyOf(optionalServices),
+            immutableSetCopyOf(serviceSets),
+            immutableSetCopyOf(serviceListings)
         );
     }
     
@@ -270,7 +271,7 @@ public final class ServiceFactoryWithDependencies<S, T extends S> extends Servic
                     final String msg = f("null result when invoking factory method %s:%s with parameters [%s]",
                         className(serviceFactory),
                         factoryMethod.toGenericString(),
-                        FluentIterable.of(values.get()).transform(RegistrationTools.TO_CLASS_NAME).join(Joiner.on(", ")));
+                        Stream.of(values.get()).map(RegistrationTools.TO_CLASS_NAME).collect(Collectors.joining(", ")));
                     LOG.error(msg);
                     throw new RegistrationException(msg);
                 }
@@ -286,7 +287,7 @@ public final class ServiceFactoryWithDependencies<S, T extends S> extends Servic
                 LOG.error(f("failed to invoke factory method %s:%s with parameters [%s]: %s: %s",
                     className(serviceFactory),
                     factoryMethod.toGenericString(),
-                    FluentIterable.of(values.get()).transform(RegistrationTools.TO_CLASS_NAME).join(Joiner.on(", ")),
+                    Stream.of(values.get()).map(RegistrationTools.TO_CLASS_NAME).collect(Collectors.joining(", ")),
                     className(t), t.getMessage()), t);
                 if (t instanceof RegistrationException) {
                     throw (RegistrationException) t;
