@@ -50,11 +50,12 @@
 package com.openexchange.util.activator.impl;
 
 import java.util.Dictionary;
-import javax.annotation.Nullable;
-import javax.annotation.ParametersAreNonnullByDefault;
+
+
 import javax.annotation.concurrent.ThreadSafe;
 import org.osgi.framework.BundleContext;
 import com.google.common.collect.ImmutableSet;
+import com.openexchange.annotation.Nullable;
 import com.openexchange.util.activator.ServiceDependencyResolver;
 import com.openexchange.util.activator.ServiceRegistrationHandler;
 
@@ -65,7 +66,6 @@ import com.openexchange.util.activator.ServiceRegistrationHandler;
  * @author <a href="mailto:pascal.bleser@open-xchange.com">Pascal Bleser</a>
  */
 @ThreadSafe
-@ParametersAreNonnullByDefault
 public class ServiceWithDependenciesServiceRegisterer<S, T extends S>
     extends InstanceFactoryServiceAwareDependentServiceRegistererTemplate<S, T> {
 
