@@ -50,23 +50,24 @@
 package com.openexchange.util.activator.impl;
 
 import static com.openexchange.util.activator.impl.RegistrationTools.TO_SIMPLE_CLASS_NAME;
+import static com.openexchange.util.custom.base.NullUtil.build;
 import static com.openexchange.util.custom.base.NullUtil.f;
+import static com.openexchange.util.custom.base.NullUtil.immutableSet;
+import static com.openexchange.util.custom.base.NullUtil.immutableSetCopyOf;
 import static com.openexchange.util.custom.base.NullUtil.logger;
 import java.util.Dictionary;
 import java.util.Set;
 import java.util.concurrent.atomic.AtomicReference;
-import javax.annotation.Nullable;
-import javax.annotation.ParametersAreNonnullByDefault;
+import java.util.stream.Collectors;
 import javax.annotation.concurrent.Immutable;
 import javax.servlet.http.HttpServlet;
 import org.osgi.framework.BundleContext;
 import org.osgi.framework.ServiceRegistration;
 import org.osgi.service.http.HttpService;
 import org.slf4j.Logger;
-import com.google.common.base.Joiner;
-import com.google.common.collect.FluentIterable;
 import com.google.common.collect.ImmutableMap;
 import com.google.common.collect.ImmutableSet;
+import com.openexchange.annotation.Nullable;
 import com.openexchange.config.ConfigurationService;
 import com.openexchange.config.Interests;
 import com.openexchange.config.Reloadable;
@@ -86,7 +87,6 @@ import com.openexchange.util.custom.base.StringInterpolator;
  * @author <a href="mailto:pascal.bleser@open-xchange.com">Pascal Bleser</a>
  * @since v7.8.2
  */
-@ParametersAreNonnullByDefault
 public abstract class ServletServiceRegistererTemplate<T extends HttpServlet> extends ServiceAwareDependentServiceRegistererTemplate<HttpServlet, T> {
 
     private static final Logger LOG = logger(ServletServiceRegistererTemplate.class);
@@ -100,13 +100,13 @@ public abstract class ServletServiceRegistererTemplate<T extends HttpServlet> ex
         if (path.contains("${")) {
             b.add(new MandatoryServiceDependency<>(ConfigurationService.class));
         }
-        return b.build();
+        return build(b);
     }
     
     public static ImmutableSet<OptionalServiceDependency<?>> withOptionalServletDependencies(
         final Iterable<OptionalServiceDependency<?>> neededServices,
         final String path) {
-        return ImmutableSet.copyOf(neededServices);
+        return immutableSetCopyOf(neededServices);
     }
 
     private final class ServletPathReloader implements Reloadable {
@@ -182,7 +182,7 @@ public abstract class ServletServiceRegistererTemplate<T extends HttpServlet> ex
                         aliasRef.compareAndSet(newAlias, null);
                         final String msg = f("failed to re-register %s (%s) with %s under '%s'",
                             serviceInstanceName,
-                            FluentIterable.from(serviceTypes).transform(TO_SIMPLE_CLASS_NAME).join(Joiner.on(", ")),
+                            serviceTypes.stream().map(TO_SIMPLE_CLASS_NAME).collect(Collectors.joining(", ")),
                             HttpService.class.getName(),
                             newAlias);
                         LOG.error(msg, e);
@@ -251,7 +251,7 @@ public abstract class ServletServiceRegistererTemplate<T extends HttpServlet> ex
         } catch (final Exception e) {
             final String msg = f("failed to create instance of %s (%s)",
                 serviceInstanceName,
-                FluentIterable.from(serviceTypes).transform(TO_SIMPLE_CLASS_NAME).join(Joiner.on(", ")));
+                serviceTypes.stream().map(TO_SIMPLE_CLASS_NAME).collect(Collectors.joining(", ")));
             LOG.error(msg, e);
             throw new RegistrationException(msg, e);
         }
@@ -290,7 +290,7 @@ public abstract class ServletServiceRegistererTemplate<T extends HttpServlet> ex
         } catch (final Exception e) {
             final String msg = f("failed to register %s (%s) with %s under '%s'",
                 serviceInstanceName,
-                FluentIterable.from(serviceTypes).transform(TO_SIMPLE_CLASS_NAME).join(Joiner.on(", ")),
+                serviceTypes.stream().map(TO_SIMPLE_CLASS_NAME).collect(Collectors.joining(", ")),
                 HttpService.class.getName(),
                 resolvedPath);
             LOG.error(msg, e);
@@ -313,7 +313,7 @@ public abstract class ServletServiceRegistererTemplate<T extends HttpServlet> ex
             final ServletPathReloader reloader = new ServletPathReloader(httpService, reloadableProps, pathTemplate, resolvedPath, serviceInstance, properties);
             final ServiceRegistration<ServletPathReloader> r = RegistrationTools.registerIntoContext(
                 context,
-                ImmutableSet.of(Reloadable.class),
+                immutableSet(Reloadable.class),
                 reloader,
                 properties
             );
